@@ -40,7 +40,7 @@ def add_authentication_arguments(parser, env):
 
 
 def add_output_formatting_arguments(parser, env):
-    formatting = parser.add_argument_group('output formatting')
+    formatting = parser.add_argument_group('input/output formatting')
 
     formatting.add_argument(
         '-f',
@@ -49,7 +49,7 @@ def add_output_formatting_arguments(parser, env):
         choices=FORMATTERS.keys(),
         default=env.get('TOWER_FORMAT', 'json'),
         help=(
-            'specify an output format'
+            'specify a format for the input and output'
         ),
     )
     formatting.add_argument(
@@ -130,7 +130,6 @@ def format_yaml(output, fmt):
     return yaml.safe_dump(
         output,
         default_flow_style=False,
-        encoding='utf-8',
         allow_unicode=True
     )
 
